#!/usr/bin/env bash
#
# This file is part of the KubeVirt project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Copyright 2024 Red Hat, Inc.
#

set -e

paths=""
while IFS= read -r line; do
    # read directory from the file and append a wildcard
    paths+="${line}/... "
done <hack/linter/lint-paths.txt

golangci-lint run --timeout 20m --verbose ${paths}
golangci-lint run --disable-all -E ginkgolinter --timeout 10m --verbose --no-config \
    ./pkg/... \
    ./tests/...
